@@ -508,6 +508,96 @@ class Update(object):
             delete_docs=True,
         ))
 
+    #
+    # Update Tokens
+    #
+    def update_tokens(self):
+        """Check stored GitHub Tokens and update as necessary."""
+        firestore_project = self.auth.settings.get('githubapp', {}).get('project')
+        firestore = self.github.firestore(app_project=firestore_project)
+
+        # get people from firestore
+        people = firestore.get_people_dict(key='google_id')
+
+        # get users from firestore
+        users = {}
+        for u in firestore.get_github_users():
+            uid = u['id']
+            users[uid] = u
+
+        remove_tokens = []
+        update_tokens = []
+
+        # get tokens from
+        for t in firestore.get_tokens():
+            github_id = int(t['github_id'])
+            github_login = t['github_login']
+
+            google_id = t['google_id']
+            google_email = t['google_email']
+
+            remove = False
+            update = False
+
+            # check google_id
+            if google_id not in people:
+                print('Google User not found: {} [{}]'.format(google_id, google_email))
+                remove = True
+
+            # check github_id
+            elif github_id not in users:
+                print('GitHub User not found: {} [{}]'.format(github_id, github_login))
+                remove = True
+
+            # check google email
+            elif google_email != people[google_id]['email_username']:
+                print('Google Email needs update: {}: {} -> {}'.format(
+                    google_id,
+                    google_email,
+                    people[google_id]['email_username'],
+                ))
+                t['google_email'] = people[google_id]['email_username']
+                update = True
+
+            # check github login
+            elif github_login != users[github_id]['login'].lower():
+                print('GitHub Login needs update: {}: {} -> {}'.format(
+                    github_id,
+                    github_login,
+                    users[github_id]['login'].lower(),
+                ))
+                t['github_login'] = users[github_id]['login'].lower()
+                update = True
+
+            if remove:
+                remove_tokens.append(t)
+            elif update:
+                update_tokens.append(t)
+
+        # update tokens that need updating
+        if update_tokens:
+            print('\nUpdating tokens for {} users...'.format(len(update_tokens)))
+            for t in sorted(update_tokens, key=lambda x: x['github_login']):
+                current = firestore.get_stored_token(t['google_id'])
+                print('   * {} [{}]'.format(
+                    current['github_login'],
+                    current['github_id'],
+                ))
+                current = firestore.get_stored_token(t['google_id'])
+                current['github_login'] = t['github_login']
+                current['google_email'] = t['google_email']
+                firestore.store_token(current)
+
+        # remove tokens that need updating
+        if remove_tokens:
+            print('\nRemoving tokens for {} users...'.format(len(remove_tokens)))
+            for t in sorted(remove_tokens, key=lambda x: x['github_login']):
+                print('   - {} [{}]'.format(
+                    t['github_login'],
+                    t['github_id'],
+                ))
+                firestore.delete_stored_token(t['google_id'])
+
     #
     # Update Users
     #
@@ -530,7 +620,7 @@ class Update(object):
                 logging.warning('Invalid token for user: {} [{}]'.format(login, github_id))
                 print('Deleting user with invalid token: {} [{}]'.format(login, github_id))
                 # delete user with invalid token from user token store
-                self.github.datastore().delete_user(github_id)
+                self.github.firestore().delete_stored_github_user(github_id)
             else:
                 logging.error('Failed to get user: {} [{}]'.format(login, github_id))
                 logging.error(e)
